# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/detection_instance_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/detection_instance_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1fsai_grpc_api/protos/detection_instance_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xa2\x04\n\x11\x44\x65tectionInstance\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\x12\x0f\n\x07part_id\x18\x03 \x01(\x05\x12\x10\n\x08image_id\x18\x04 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x05 \x01(\x0b\x32\x08.GeoBbox\x12\x14\n\x0c\x64\x65tection_id\x18\x06 \x01(\x05\x12\x11\n\tsource_id\x18\x07 \x01(\x05\x12\x1b\n\x13source_detection_id\x18\x08 \x01(\t\x12\r\n\x05score\x18\t \x01(\x02\x12\x0e\n\x06height\x18\n \x01(\x02\x12\x17\n\x0fheight_inferred\x18\x0b \x01(\x08\x12\x35\n\x11human_verified_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x64\x65tected_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x63\x61tegory_id\x18\x10 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x11 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x12 \x01(\x0b\x32\t.GeoPoint\"Z\n2CacheDetectionInstancesDataByMissionImageIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\x12\x10\n\x08image_id\x18\x02 \x01(\x05\"\x88\x01\n3CacheDetectionInstancesDataByMissionImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"V\n$FindOrCreateDetectionInstanceRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"y\n%FindOrCreateDetectionInstanceResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"T\n,GetDetectionInstancesByMissionImageIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\x12\x10\n\x08image_id\x18\x02 \x01(\x05\"\x82\x01\n-GetDetectionInstancesByMissionImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"W\n%UpdateDetectionInstanceGeoBboxRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"z\n&UpdateDetectionInstanceGeoBboxResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"T\n\"DeleteDetectionInstanceByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n#DeleteDetectionInstanceByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"M\n\x1bSetHumanVerifiedByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"p\n\x1cSetHumanVerifiedByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"U\n#GetDetectionInstanceDataByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"M\n$GetDetectionInstanceDataByIdResponse\x12%\n\x1d\x64\x65tection_instance_data_bytes\x18\x01 \x01(\x0c\"j\n\'TransitionDetectionInstanceStateRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x0f\n\x07trigger\x18\x02 \x01(\t\"\x8b\x01\n(TransitionDetectionInstanceStateResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\r\n\x05state\x18\x02 \x01(\t\x12.\n\x12\x64\x65tection_instance\x18\x03 \x01(\x0b\x32\x12.DetectionInstance\"U\n#GetDetectionInstanceBboxByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n$GetDetectionInstanceBboxByIdResponse\x12\r\n\x05min_x\x18\x01 \x01(\x05\x12\r\n\x05max_x\x18\x02 \x01(\x05\x12\r\n\x05min_y\x18\x03 \x01(\x05\x12\r\n\x05max_y\x18\x04 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x05 \x01(\x05\"\x9c\x01\n\'FindOrCreateShadowPointGeoPointsRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"|\n(FindOrCreateShadowPointGeoPointsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\x9c\x01\n\'UpdateDetectionInstanceGeoPointsRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"|\n(UpdateDetectionInstanceGeoPointsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance2\xb2\n\n\x14\x44\x65tectionInstanceApi\x12\x98\x01\n+CacheDetectionInstancesDataByMissionImageId\x12\x33.CacheDetectionInstancesDataByMissionImageIdRequest\x1a\x34.CacheDetectionInstancesDataByMissionImageIdResponse\x12h\n\x1b\x44\x65leteDetectionInstanceById\x12#.DeleteDetectionInstanceByIdRequest\x1a$.DeleteDetectionInstanceByIdResponse\x12n\n\x1d\x46indOrCreateDetectionInstance\x12%.FindOrCreateDetectionInstanceRequest\x1a&.FindOrCreateDetectionInstanceResponse\x12m\n\x1cGetDetectionInstanceDataById\x12$.GetDetectionInstanceDataByIdRequest\x1a%.GetDetectionInstanceDataByIdResponse0\x01\x12\x86\x01\n%GetDetectionInstancesByMissionImageId\x12-.GetDetectionInstancesByMissionImageIdRequest\x1a..GetDetectionInstancesByMissionImageIdResponse\x12\x62\n#SetDetectionInstanceAsHumanVerified\x12\x1c.SetHumanVerifiedByIdRequest\x1a\x1d.SetHumanVerifiedByIdResponse\x12w\n TransitionDetectionInstanceState\x12(.TransitionDetectionInstanceStateRequest\x1a).TransitionDetectionInstanceStateResponse\x12q\n\x1eUpdateDetectionInstanceGeoBbox\x12&.UpdateDetectionInstanceGeoBboxRequest\x1a\'.UpdateDetectionInstanceGeoBboxResponse\x12k\n\x1cGetDetectionInstanceBboxById\x12$.GetDetectionInstanceBboxByIdRequest\x1a%.GetDetectionInstanceBboxByIdResponse\x12w\n FindOrCreateShadowPointGeoPoints\x12(.FindOrCreateShadowPointGeoPointsRequest\x1a).FindOrCreateShadowPointGeoPointsResponse\x12w\n UpdateDetectionInstanceGeoPoints\x12(.UpdateDetectionInstanceGeoPointsRequest\x1a).UpdateDetectionInstanceGeoPointsResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_DETECTIONINSTANCE = _descriptor.Descriptor(
  name='DetectionInstance',
  full_name='DetectionInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='DetectionInstance.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='DetectionInstance.workflow_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='part_id', full_name='DetectionInstance.part_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='DetectionInstance.image_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_bbox', full_name='DetectionInstance.geo_bbox', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_id', full_name='DetectionInstance.detection_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='DetectionInstance.source_id', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_detection_id', full_name='DetectionInstance.source_detection_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='DetectionInstance.score', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='DetectionInstance.height', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height_inferred', full_name='DetectionInstance.height_inferred', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='human_verified_at', full_name='DetectionInstance.human_verified_at', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detected_at', full_name='DetectionInstance.detected_at', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='DetectionInstance.created_at', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='DetectionInstance.updated_at', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_id', full_name='DetectionInstance.category_id', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_start', full_name='DetectionInstance.geo_point_shadow_start', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_end', full_name='DetectionInstance.geo_point_shadow_end', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=667,
)


_CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDREQUEST = _descriptor.Descriptor(
  name='CacheDetectionInstancesDataByMissionImageIdRequest',
  full_name='CacheDetectionInstancesDataByMissionImageIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='CacheDetectionInstancesDataByMissionImageIdRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='CacheDetectionInstancesDataByMissionImageIdRequest.image_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=759,
)


_CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDRESPONSE = _descriptor.Descriptor(
  name='CacheDetectionInstancesDataByMissionImageIdResponse',
  full_name='CacheDetectionInstancesDataByMissionImageIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CacheDetectionInstancesDataByMissionImageIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instances', full_name='CacheDetectionInstancesDataByMissionImageIdResponse.detection_instances', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=762,
  serialized_end=898,
)


_FINDORCREATEDETECTIONINSTANCEREQUEST = _descriptor.Descriptor(
  name='FindOrCreateDetectionInstanceRequest',
  full_name='FindOrCreateDetectionInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateDetectionInstanceRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=986,
)


_FINDORCREATEDETECTIONINSTANCERESPONSE = _descriptor.Descriptor(
  name='FindOrCreateDetectionInstanceResponse',
  full_name='FindOrCreateDetectionInstanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateDetectionInstanceResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateDetectionInstanceResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=988,
  serialized_end=1109,
)


_GETDETECTIONINSTANCESBYMISSIONIMAGEIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstancesByMissionImageIdRequest',
  full_name='GetDetectionInstancesByMissionImageIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='GetDetectionInstancesByMissionImageIdRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='GetDetectionInstancesByMissionImageIdRequest.image_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1195,
)


_GETDETECTIONINSTANCESBYMISSIONIMAGEIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstancesByMissionImageIdResponse',
  full_name='GetDetectionInstancesByMissionImageIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetDetectionInstancesByMissionImageIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instances', full_name='GetDetectionInstancesByMissionImageIdResponse.detection_instances', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1328,
)


_UPDATEDETECTIONINSTANCEGEOBBOXREQUEST = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoBboxRequest',
  full_name='UpdateDetectionInstanceGeoBboxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoBboxRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1330,
  serialized_end=1417,
)


_UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoBboxResponse',
  full_name='UpdateDetectionInstanceGeoBboxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateDetectionInstanceGeoBboxResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoBboxResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1541,
)


_DELETEDETECTIONINSTANCEBYIDREQUEST = _descriptor.Descriptor(
  name='DeleteDetectionInstanceByIdRequest',
  full_name='DeleteDetectionInstanceByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='DeleteDetectionInstanceByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1543,
  serialized_end=1627,
)


_DELETEDETECTIONINSTANCEBYIDRESPONSE = _descriptor.Descriptor(
  name='DeleteDetectionInstanceByIdResponse',
  full_name='DeleteDetectionInstanceByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteDetectionInstanceByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='DeleteDetectionInstanceByIdResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1629,
  serialized_end=1748,
)


_SETHUMANVERIFIEDBYIDREQUEST = _descriptor.Descriptor(
  name='SetHumanVerifiedByIdRequest',
  full_name='SetHumanVerifiedByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='SetHumanVerifiedByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1827,
)


_SETHUMANVERIFIEDBYIDRESPONSE = _descriptor.Descriptor(
  name='SetHumanVerifiedByIdResponse',
  full_name='SetHumanVerifiedByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='SetHumanVerifiedByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='SetHumanVerifiedByIdResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1829,
  serialized_end=1941,
)


_GETDETECTIONINSTANCEDATABYIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstanceDataByIdRequest',
  full_name='GetDetectionInstanceDataByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceDataByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1943,
  serialized_end=2028,
)


_GETDETECTIONINSTANCEDATABYIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstanceDataByIdResponse',
  full_name='GetDetectionInstanceDataByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance_data_bytes', full_name='GetDetectionInstanceDataByIdResponse.detection_instance_data_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2030,
  serialized_end=2107,
)


_TRANSITIONDETECTIONINSTANCESTATEREQUEST = _descriptor.Descriptor(
  name='TransitionDetectionInstanceStateRequest',
  full_name='TransitionDetectionInstanceStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='TransitionDetectionInstanceStateRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='TransitionDetectionInstanceStateRequest.trigger', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2109,
  serialized_end=2215,
)


_TRANSITIONDETECTIONINSTANCESTATERESPONSE = _descriptor.Descriptor(
  name='TransitionDetectionInstanceStateResponse',
  full_name='TransitionDetectionInstanceStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='TransitionDetectionInstanceStateResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='TransitionDetectionInstanceStateResponse.state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='TransitionDetectionInstanceStateResponse.detection_instance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2218,
  serialized_end=2357,
)


_GETDETECTIONINSTANCEBBOXBYIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstanceBboxByIdRequest',
  full_name='GetDetectionInstanceBboxByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceBboxByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2359,
  serialized_end=2444,
)


_GETDETECTIONINSTANCEBBOXBYIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstanceBboxByIdResponse',
  full_name='GetDetectionInstanceBboxByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_x', full_name='GetDetectionInstanceBboxByIdResponse.min_x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_x', full_name='GetDetectionInstanceBboxByIdResponse.max_x', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_y', full_name='GetDetectionInstanceBboxByIdResponse.min_y', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_y', full_name='GetDetectionInstanceBboxByIdResponse.max_y', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_id', full_name='GetDetectionInstanceBboxByIdResponse.category_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2446,
  serialized_end=2565,
)


_FINDORCREATESHADOWPOINTGEOPOINTSREQUEST = _descriptor.Descriptor(
  name='FindOrCreateShadowPointGeoPointsRequest',
  full_name='FindOrCreateShadowPointGeoPointsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance_id', full_name='FindOrCreateShadowPointGeoPointsRequest.detection_instance_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_start', full_name='FindOrCreateShadowPointGeoPointsRequest.geo_point_shadow_start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_end', full_name='FindOrCreateShadowPointGeoPointsRequest.geo_point_shadow_end', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2568,
  serialized_end=2724,
)


_FINDORCREATESHADOWPOINTGEOPOINTSRESPONSE = _descriptor.Descriptor(
  name='FindOrCreateShadowPointGeoPointsResponse',
  full_name='FindOrCreateShadowPointGeoPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateShadowPointGeoPointsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateShadowPointGeoPointsResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2850,
)


_UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoPointsRequest',
  full_name='UpdateDetectionInstanceGeoPointsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance_id', full_name='UpdateDetectionInstanceGeoPointsRequest.detection_instance_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_start', full_name='UpdateDetectionInstanceGeoPointsRequest.geo_point_shadow_start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_end', full_name='UpdateDetectionInstanceGeoPointsRequest.geo_point_shadow_end', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2853,
  serialized_end=3009,
)


_UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoPointsResponse',
  full_name='UpdateDetectionInstanceGeoPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateDetectionInstanceGeoPointsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoPointsResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3011,
  serialized_end=3135,
)

_DETECTIONINSTANCE.fields_by_name['geo_bbox'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOBBOX
_DETECTIONINSTANCE.fields_by_name['human_verified_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['detected_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['geo_point_shadow_start'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_DETECTIONINSTANCE.fields_by_name['geo_point_shadow_end'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDRESPONSE.fields_by_name['detection_instances'].message_type = _DETECTIONINSTANCE
_FINDORCREATEDETECTIONINSTANCEREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_FINDORCREATEDETECTIONINSTANCERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEDETECTIONINSTANCERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCESBYMISSIONIMAGEIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETDETECTIONINSTANCESBYMISSIONIMAGEIDRESPONSE.fields_by_name['detection_instances'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOBBOXREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_DELETEDETECTIONINSTANCEBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_DELETEDETECTIONINSTANCEBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_DELETEDETECTIONINSTANCEBYIDRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_SETHUMANVERIFIEDBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_SETHUMANVERIFIEDBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_SETHUMANVERIFIEDBYIDRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCEDATABYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_TRANSITIONDETECTIONINSTANCESTATEREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_TRANSITIONDETECTIONINSTANCESTATERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_TRANSITIONDETECTIONINSTANCESTATERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCEBBOXBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_FINDORCREATESHADOWPOINTGEOPOINTSREQUEST.fields_by_name['geo_point_shadow_start'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_FINDORCREATESHADOWPOINTGEOPOINTSREQUEST.fields_by_name['geo_point_shadow_end'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_FINDORCREATESHADOWPOINTGEOPOINTSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATESHADOWPOINTGEOPOINTSRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST.fields_by_name['geo_point_shadow_start'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST.fields_by_name['geo_point_shadow_end'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
DESCRIPTOR.message_types_by_name['DetectionInstance'] = _DETECTIONINSTANCE
DESCRIPTOR.message_types_by_name['CacheDetectionInstancesDataByMissionImageIdRequest'] = _CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDREQUEST
DESCRIPTOR.message_types_by_name['CacheDetectionInstancesDataByMissionImageIdResponse'] = _CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDRESPONSE
DESCRIPTOR.message_types_by_name['FindOrCreateDetectionInstanceRequest'] = _FINDORCREATEDETECTIONINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateDetectionInstanceResponse'] = _FINDORCREATEDETECTIONINSTANCERESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstancesByMissionImageIdRequest'] = _GETDETECTIONINSTANCESBYMISSIONIMAGEIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstancesByMissionImageIdResponse'] = _GETDETECTIONINSTANCESBYMISSIONIMAGEIDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoBboxRequest'] = _UPDATEDETECTIONINSTANCEGEOBBOXREQUEST
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoBboxResponse'] = _UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDetectionInstanceByIdRequest'] = _DELETEDETECTIONINSTANCEBYIDREQUEST
DESCRIPTOR.message_types_by_name['DeleteDetectionInstanceByIdResponse'] = _DELETEDETECTIONINSTANCEBYIDRESPONSE
DESCRIPTOR.message_types_by_name['SetHumanVerifiedByIdRequest'] = _SETHUMANVERIFIEDBYIDREQUEST
DESCRIPTOR.message_types_by_name['SetHumanVerifiedByIdResponse'] = _SETHUMANVERIFIEDBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstanceDataByIdRequest'] = _GETDETECTIONINSTANCEDATABYIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstanceDataByIdResponse'] = _GETDETECTIONINSTANCEDATABYIDRESPONSE
DESCRIPTOR.message_types_by_name['TransitionDetectionInstanceStateRequest'] = _TRANSITIONDETECTIONINSTANCESTATEREQUEST
DESCRIPTOR.message_types_by_name['TransitionDetectionInstanceStateResponse'] = _TRANSITIONDETECTIONINSTANCESTATERESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstanceBboxByIdRequest'] = _GETDETECTIONINSTANCEBBOXBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstanceBboxByIdResponse'] = _GETDETECTIONINSTANCEBBOXBYIDRESPONSE
DESCRIPTOR.message_types_by_name['FindOrCreateShadowPointGeoPointsRequest'] = _FINDORCREATESHADOWPOINTGEOPOINTSREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateShadowPointGeoPointsResponse'] = _FINDORCREATESHADOWPOINTGEOPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoPointsRequest'] = _UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoPointsResponse'] = _UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DetectionInstance = _reflection.GeneratedProtocolMessageType('DetectionInstance', (_message.Message,), {
  'DESCRIPTOR' : _DETECTIONINSTANCE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DetectionInstance)
  })
_sym_db.RegisterMessage(DetectionInstance)

CacheDetectionInstancesDataByMissionImageIdRequest = _reflection.GeneratedProtocolMessageType('CacheDetectionInstancesDataByMissionImageIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:CacheDetectionInstancesDataByMissionImageIdRequest)
  })
_sym_db.RegisterMessage(CacheDetectionInstancesDataByMissionImageIdRequest)

CacheDetectionInstancesDataByMissionImageIdResponse = _reflection.GeneratedProtocolMessageType('CacheDetectionInstancesDataByMissionImageIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:CacheDetectionInstancesDataByMissionImageIdResponse)
  })
_sym_db.RegisterMessage(CacheDetectionInstancesDataByMissionImageIdResponse)

FindOrCreateDetectionInstanceRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateDetectionInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEDETECTIONINSTANCEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateDetectionInstanceRequest)
  })
_sym_db.RegisterMessage(FindOrCreateDetectionInstanceRequest)

FindOrCreateDetectionInstanceResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateDetectionInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEDETECTIONINSTANCERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateDetectionInstanceResponse)
  })
_sym_db.RegisterMessage(FindOrCreateDetectionInstanceResponse)

GetDetectionInstancesByMissionImageIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstancesByMissionImageIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCESBYMISSIONIMAGEIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstancesByMissionImageIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstancesByMissionImageIdRequest)

GetDetectionInstancesByMissionImageIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstancesByMissionImageIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCESBYMISSIONIMAGEIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstancesByMissionImageIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstancesByMissionImageIdResponse)

UpdateDetectionInstanceGeoBboxRequest = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoBboxRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOBBOXREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoBboxRequest)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoBboxRequest)

UpdateDetectionInstanceGeoBboxResponse = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoBboxResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoBboxResponse)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoBboxResponse)

DeleteDetectionInstanceByIdRequest = _reflection.GeneratedProtocolMessageType('DeleteDetectionInstanceByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDETECTIONINSTANCEBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteDetectionInstanceByIdRequest)
  })
_sym_db.RegisterMessage(DeleteDetectionInstanceByIdRequest)

DeleteDetectionInstanceByIdResponse = _reflection.GeneratedProtocolMessageType('DeleteDetectionInstanceByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDETECTIONINSTANCEBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteDetectionInstanceByIdResponse)
  })
_sym_db.RegisterMessage(DeleteDetectionInstanceByIdResponse)

SetHumanVerifiedByIdRequest = _reflection.GeneratedProtocolMessageType('SetHumanVerifiedByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETHUMANVERIFIEDBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:SetHumanVerifiedByIdRequest)
  })
_sym_db.RegisterMessage(SetHumanVerifiedByIdRequest)

SetHumanVerifiedByIdResponse = _reflection.GeneratedProtocolMessageType('SetHumanVerifiedByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETHUMANVERIFIEDBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:SetHumanVerifiedByIdResponse)
  })
_sym_db.RegisterMessage(SetHumanVerifiedByIdResponse)

GetDetectionInstanceDataByIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceDataByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEDATABYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceDataByIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstanceDataByIdRequest)

GetDetectionInstanceDataByIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceDataByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEDATABYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceDataByIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstanceDataByIdResponse)

TransitionDetectionInstanceStateRequest = _reflection.GeneratedProtocolMessageType('TransitionDetectionInstanceStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONDETECTIONINSTANCESTATEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionDetectionInstanceStateRequest)
  })
_sym_db.RegisterMessage(TransitionDetectionInstanceStateRequest)

TransitionDetectionInstanceStateResponse = _reflection.GeneratedProtocolMessageType('TransitionDetectionInstanceStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONDETECTIONINSTANCESTATERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionDetectionInstanceStateResponse)
  })
_sym_db.RegisterMessage(TransitionDetectionInstanceStateResponse)

GetDetectionInstanceBboxByIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceBboxByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEBBOXBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceBboxByIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstanceBboxByIdRequest)

GetDetectionInstanceBboxByIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceBboxByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEBBOXBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceBboxByIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstanceBboxByIdResponse)

FindOrCreateShadowPointGeoPointsRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateShadowPointGeoPointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATESHADOWPOINTGEOPOINTSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateShadowPointGeoPointsRequest)
  })
_sym_db.RegisterMessage(FindOrCreateShadowPointGeoPointsRequest)

FindOrCreateShadowPointGeoPointsResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateShadowPointGeoPointsResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATESHADOWPOINTGEOPOINTSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateShadowPointGeoPointsResponse)
  })
_sym_db.RegisterMessage(FindOrCreateShadowPointGeoPointsResponse)

UpdateDetectionInstanceGeoPointsRequest = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoPointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoPointsRequest)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoPointsRequest)

UpdateDetectionInstanceGeoPointsResponse = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoPointsResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoPointsResponse)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoPointsResponse)



_DETECTIONINSTANCEAPI = _descriptor.ServiceDescriptor(
  name='DetectionInstanceApi',
  full_name='DetectionInstanceApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3138,
  serialized_end=4468,
  methods=[
  _descriptor.MethodDescriptor(
    name='CacheDetectionInstancesDataByMissionImageId',
    full_name='DetectionInstanceApi.CacheDetectionInstancesDataByMissionImageId',
    index=0,
    containing_service=None,
    input_type=_CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDREQUEST,
    output_type=_CACHEDETECTIONINSTANCESDATABYMISSIONIMAGEIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDetectionInstanceById',
    full_name='DetectionInstanceApi.DeleteDetectionInstanceById',
    index=1,
    containing_service=None,
    input_type=_DELETEDETECTIONINSTANCEBYIDREQUEST,
    output_type=_DELETEDETECTIONINSTANCEBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindOrCreateDetectionInstance',
    full_name='DetectionInstanceApi.FindOrCreateDetectionInstance',
    index=2,
    containing_service=None,
    input_type=_FINDORCREATEDETECTIONINSTANCEREQUEST,
    output_type=_FINDORCREATEDETECTIONINSTANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstanceDataById',
    full_name='DetectionInstanceApi.GetDetectionInstanceDataById',
    index=3,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCEDATABYIDREQUEST,
    output_type=_GETDETECTIONINSTANCEDATABYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstancesByMissionImageId',
    full_name='DetectionInstanceApi.GetDetectionInstancesByMissionImageId',
    index=4,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCESBYMISSIONIMAGEIDREQUEST,
    output_type=_GETDETECTIONINSTANCESBYMISSIONIMAGEIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDetectionInstanceAsHumanVerified',
    full_name='DetectionInstanceApi.SetDetectionInstanceAsHumanVerified',
    index=5,
    containing_service=None,
    input_type=_SETHUMANVERIFIEDBYIDREQUEST,
    output_type=_SETHUMANVERIFIEDBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransitionDetectionInstanceState',
    full_name='DetectionInstanceApi.TransitionDetectionInstanceState',
    index=6,
    containing_service=None,
    input_type=_TRANSITIONDETECTIONINSTANCESTATEREQUEST,
    output_type=_TRANSITIONDETECTIONINSTANCESTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDetectionInstanceGeoBbox',
    full_name='DetectionInstanceApi.UpdateDetectionInstanceGeoBbox',
    index=7,
    containing_service=None,
    input_type=_UPDATEDETECTIONINSTANCEGEOBBOXREQUEST,
    output_type=_UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstanceBboxById',
    full_name='DetectionInstanceApi.GetDetectionInstanceBboxById',
    index=8,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCEBBOXBYIDREQUEST,
    output_type=_GETDETECTIONINSTANCEBBOXBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindOrCreateShadowPointGeoPoints',
    full_name='DetectionInstanceApi.FindOrCreateShadowPointGeoPoints',
    index=9,
    containing_service=None,
    input_type=_FINDORCREATESHADOWPOINTGEOPOINTSREQUEST,
    output_type=_FINDORCREATESHADOWPOINTGEOPOINTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDetectionInstanceGeoPoints',
    full_name='DetectionInstanceApi.UpdateDetectionInstanceGeoPoints',
    index=10,
    containing_service=None,
    input_type=_UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST,
    output_type=_UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DETECTIONINSTANCEAPI)

DESCRIPTOR.services_by_name['DetectionInstanceApi'] = _DETECTIONINSTANCEAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/team_member_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/team_member_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*fsai_grpc_api/protos/team_member_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xca\x01\n\nTeamMember\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12\x0f\n\x07team_id\x18\x03 \x01(\x05\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"A\n\x1d\x46indOrCreateTeamMemberRequest\x12 \n\x0bteam_member\x18\x01 \x01(\x0b\x32\x0b.TeamMember\"d\n\x1e\x46indOrCreateTeamMemberResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12 \n\x0bteam_member\x18\x02 \x01(\x0b\x32\x0b.TeamMember2j\n\rTeamMemberApi\x12Y\n\x16\x46indOrCreateTeamMember\x12\x1e.FindOrCreateTeamMemberRequest\x1a\x1f.FindOrCreateTeamMemberResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_TEAMMEMBER = _descriptor.Descriptor(
  name='TeamMember',
  full_name='TeamMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='TeamMember.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='TeamMember.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='TeamMember.team_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='TeamMember.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='TeamMember.updated_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='TeamMember.deleted_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=316,
)


_FINDORCREATETEAMMEMBERREQUEST = _descriptor.Descriptor(
  name='FindOrCreateTeamMemberRequest',
  full_name='FindOrCreateTeamMemberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_member', full_name='FindOrCreateTeamMemberRequest.team_member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=383,
)


_FINDORCREATETEAMMEMBERRESPONSE = _descriptor.Descriptor(
  name='FindOrCreateTeamMemberResponse',
  full_name='FindOrCreateTeamMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateTeamMemberResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='team_member', full_name='FindOrCreateTeamMemberResponse.team_member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=485,
)

_TEAMMEMBER.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEAMMEMBER.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEAMMEMBER.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FINDORCREATETEAMMEMBERREQUEST.fields_by_name['team_member'].message_type = _TEAMMEMBER
_FINDORCREATETEAMMEMBERRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATETEAMMEMBERRESPONSE.fields_by_name['team_member'].message_type = _TEAMMEMBER
DESCRIPTOR.message_types_by_name['TeamMember'] = _TEAMMEMBER
DESCRIPTOR.message_types_by_name['FindOrCreateTeamMemberRequest'] = _FINDORCREATETEAMMEMBERREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateTeamMemberResponse'] = _FINDORCREATETEAMMEMBERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TeamMember = _reflection.GeneratedProtocolMessageType('TeamMember', (_message.Message,), {
  'DESCRIPTOR' : _TEAMMEMBER,
  '__module__' : 'fsai_grpc_api.protos.team_member_api_pb2'
  # @@protoc_insertion_point(class_scope:TeamMember)
  })
_sym_db.RegisterMessage(TeamMember)

FindOrCreateTeamMemberRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateTeamMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATETEAMMEMBERREQUEST,
  '__module__' : 'fsai_grpc_api.protos.team_member_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateTeamMemberRequest)
  })
_sym_db.RegisterMessage(FindOrCreateTeamMemberRequest)

FindOrCreateTeamMemberResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateTeamMemberResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATETEAMMEMBERRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.team_member_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateTeamMemberResponse)
  })
_sym_db.RegisterMessage(FindOrCreateTeamMemberResponse)



_TEAMMEMBERAPI = _descriptor.ServiceDescriptor(
  name='TeamMemberApi',
  full_name='TeamMemberApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=487,
  serialized_end=593,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateTeamMember',
    full_name='TeamMemberApi.FindOrCreateTeamMember',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATETEAMMEMBERREQUEST,
    output_type=_FINDORCREATETEAMMEMBERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TEAMMEMBERAPI)

DESCRIPTOR.services_by_name['TeamMemberApi'] = _TEAMMEMBERAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/workflow_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/workflow_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'fsai_grpc_api/protos/workflow_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a fsai_grpc_api/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xe1\x01\n\x08Workflow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\".\n\x0fWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Q\n\x10WorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\">\n\x1fTransitionWorkflowStatusRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"a\n TransitionWorkflowStatusResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"6\n\x17QueueMissionScanRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Y\n\x18QueueMissionScanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"`\n\x1eListQueuedMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"6\n\x17ListMissionScansRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Z\n\x18ListMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"A\n\"ListRelatedMissionScansByIdRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"e\n#ListRelatedMissionScansByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"8\n\x19QueueMissionExportRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"[\n\x1aQueueMissionExportResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"b\n ListQueuedMissionExportsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"8\n\x19ListMissionExportsRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"\\\n\x1aListMissionExportsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"4\n\x15\x44\x65leteWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"W\n\x16\x44\x65leteWorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow2\xb2\x06\n\x0bWorkflowApi\x12;\n\x14\x46indOrCreateWorkflow\x12\x10.WorkflowRequest\x1a\x11.WorkflowResponse\x12_\n\x18TransitionWorkflowStatus\x12 .TransitionWorkflowStatusRequest\x1a!.TransitionWorkflowStatusResponse\x12\x41\n\x0e\x44\x65leteWorkflow\x12\x16.DeleteWorkflowRequest\x1a\x17.DeleteWorkflowResponse\x12M\n\x12QueueMissionExport\x12\x1a.QueueMissionExportRequest\x1a\x1b.QueueMissionExportResponse\x12U\n\x18ListQueuedMissionExports\x12\x16.google.protobuf.Empty\x1a!.ListQueuedMissionExportsResponse\x12M\n\x12ListMissionExports\x12\x1a.ListMissionExportsRequest\x1a\x1b.ListMissionExportsResponse\x12G\n\x10QueueMissionScan\x12\x18.QueueMissionScanRequest\x1a\x19.QueueMissionScanResponse\x12Q\n\x16ListQueuedMissionScans\x12\x16.google.protobuf.Empty\x1a\x1f.ListQueuedMissionScansResponse\x12G\n\x10ListMissionScans\x12\x18.ListMissionScansRequest\x1a\x19.ListMissionScansResponse\x12h\n\x1bListRelatedMissionScansById\x12#.ListRelatedMissionScansByIdRequest\x1a$.ListRelatedMissionScansByIdResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_WORKFLOW = _descriptor.Descriptor(
  name='Workflow',
  full_name='Workflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Workflow.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='Workflow.mission_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Workflow.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Workflow.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Workflow.status', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Workflow.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Workflow.updated_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='Workflow.metadata', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=395,
)


_WORKFLOWREQUEST = _descriptor.Descriptor(
  name='WorkflowRequest',
  full_name='WorkflowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='WorkflowRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=443,
)


_WORKFLOWRESPONSE = _descriptor.Descriptor(
  name='WorkflowResponse',
  full_name='WorkflowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='WorkflowResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='WorkflowResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=526,
)


_TRANSITIONWORKFLOWSTATUSREQUEST = _descriptor.Descriptor(
  name='TransitionWorkflowStatusRequest',
  full_name='TransitionWorkflowStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='TransitionWorkflowStatusRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=590,
)


_TRANSITIONWORKFLOWSTATUSRESPONSE = _descriptor.Descriptor(
  name='TransitionWorkflowStatusResponse',
  full_name='TransitionWorkflowStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='TransitionWorkflowStatusResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='TransitionWorkflowStatusResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=689,
)


_QUEUEMISSIONSCANREQUEST = _descriptor.Descriptor(
  name='QueueMissionScanRequest',
  full_name='QueueMissionScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionScanRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=745,
)


_QUEUEMISSIONSCANRESPONSE = _descriptor.Descriptor(
  name='QueueMissionScanResponse',
  full_name='QueueMissionScanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='QueueMissionScanResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionScanResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=836,
)


_LISTQUEUEDMISSIONSCANSRESPONSE = _descriptor.Descriptor(
  name='ListQueuedMissionScansResponse',
  full_name='ListQueuedMissionScansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListQueuedMissionScansResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListQueuedMissionScansResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=934,
)


_LISTMISSIONSCANSREQUEST = _descriptor.Descriptor(
  name='ListMissionScansRequest',
  full_name='ListMissionScansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ListMissionScansRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=990,
)


_LISTMISSIONSCANSRESPONSE = _descriptor.Descriptor(
  name='ListMissionScansResponse',
  full_name='ListMissionScansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListMissionScansResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListMissionScansResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1082,
)


_LISTRELATEDMISSIONSCANSBYIDREQUEST = _descriptor.Descriptor(
  name='ListRelatedMissionScansByIdRequest',
  full_name='ListRelatedMissionScansByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ListRelatedMissionScansByIdRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1149,
)


_LISTRELATEDMISSIONSCANSBYIDRESPONSE = _descriptor.Descriptor(
  name='ListRelatedMissionScansByIdResponse',
  full_name='ListRelatedMissionScansByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListRelatedMissionScansByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListRelatedMissionScansByIdResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1252,
)


_QUEUEMISSIONEXPORTREQUEST = _descriptor.Descriptor(
  name='QueueMissionExportRequest',
  full_name='QueueMissionExportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionExportRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1254,
  serialized_end=1310,
)


_QUEUEMISSIONEXPORTRESPONSE = _descriptor.Descriptor(
  name='QueueMissionExportResponse',
  full_name='QueueMissionExportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='QueueMissionExportResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='QueueMissionExportResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1403,
)


_LISTQUEUEDMISSIONEXPORTSRESPONSE = _descriptor.Descriptor(
  name='ListQueuedMissionExportsResponse',
  full_name='ListQueuedMissionExportsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListQueuedMissionExportsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListQueuedMissionExportsResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1405,
  serialized_end=1503,
)


_LISTMISSIONEXPORTSREQUEST = _descriptor.Descriptor(
  name='ListMissionExportsRequest',
  full_name='ListMissionExportsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ListMissionExportsRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1561,
)


_LISTMISSIONEXPORTSRESPONSE = _descriptor.Descriptor(
  name='ListMissionExportsResponse',
  full_name='ListMissionExportsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListMissionExportsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflows', full_name='ListMissionExportsResponse.workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1563,
  serialized_end=1655,
)


_DELETEWORKFLOWREQUEST = _descriptor.Descriptor(
  name='DeleteWorkflowRequest',
  full_name='DeleteWorkflowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='DeleteWorkflowRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1657,
  serialized_end=1709,
)


_DELETEWORKFLOWRESPONSE = _descriptor.Descriptor(
  name='DeleteWorkflowResponse',
  full_name='DeleteWorkflowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteWorkflowResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='DeleteWorkflowResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1798,
)

_WORKFLOW.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_WORKFLOWREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_WORKFLOWRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_WORKFLOWRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_TRANSITIONWORKFLOWSTATUSREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_TRANSITIONWORKFLOWSTATUSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_TRANSITIONWORKFLOWSTATUSRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_QUEUEMISSIONSCANREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_QUEUEMISSIONSCANRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_QUEUEMISSIONSCANRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTQUEUEDMISSIONSCANSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTQUEUEDMISSIONSCANSRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_LISTMISSIONSCANSREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTMISSIONSCANSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTMISSIONSCANSRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_LISTRELATEDMISSIONSCANSBYIDREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTRELATEDMISSIONSCANSBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTRELATEDMISSIONSCANSBYIDRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_QUEUEMISSIONEXPORTREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_QUEUEMISSIONEXPORTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_QUEUEMISSIONEXPORTRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTQUEUEDMISSIONEXPORTSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTQUEUEDMISSIONEXPORTSRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_LISTMISSIONEXPORTSREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_LISTMISSIONEXPORTSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTMISSIONEXPORTSRESPONSE.fields_by_name['workflows'].message_type = _WORKFLOW
_DELETEWORKFLOWREQUEST.fields_by_name['workflow'].message_type = _WORKFLOW
_DELETEWORKFLOWRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_DELETEWORKFLOWRESPONSE.fields_by_name['workflow'].message_type = _WORKFLOW
DESCRIPTOR.message_types_by_name['Workflow'] = _WORKFLOW
DESCRIPTOR.message_types_by_name['WorkflowRequest'] = _WORKFLOWREQUEST
DESCRIPTOR.message_types_by_name['WorkflowResponse'] = _WORKFLOWRESPONSE
DESCRIPTOR.message_types_by_name['TransitionWorkflowStatusRequest'] = _TRANSITIONWORKFLOWSTATUSREQUEST
DESCRIPTOR.message_types_by_name['TransitionWorkflowStatusResponse'] = _TRANSITIONWORKFLOWSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['QueueMissionScanRequest'] = _QUEUEMISSIONSCANREQUEST
DESCRIPTOR.message_types_by_name['QueueMissionScanResponse'] = _QUEUEMISSIONSCANRESPONSE
DESCRIPTOR.message_types_by_name['ListQueuedMissionScansResponse'] = _LISTQUEUEDMISSIONSCANSRESPONSE
DESCRIPTOR.message_types_by_name['ListMissionScansRequest'] = _LISTMISSIONSCANSREQUEST
DESCRIPTOR.message_types_by_name['ListMissionScansResponse'] = _LISTMISSIONSCANSRESPONSE
DESCRIPTOR.message_types_by_name['ListRelatedMissionScansByIdRequest'] = _LISTRELATEDMISSIONSCANSBYIDREQUEST
DESCRIPTOR.message_types_by_name['ListRelatedMissionScansByIdResponse'] = _LISTRELATEDMISSIONSCANSBYIDRESPONSE
DESCRIPTOR.message_types_by_name['QueueMissionExportRequest'] = _QUEUEMISSIONEXPORTREQUEST
DESCRIPTOR.message_types_by_name['QueueMissionExportResponse'] = _QUEUEMISSIONEXPORTRESPONSE
DESCRIPTOR.message_types_by_name['ListQueuedMissionExportsResponse'] = _LISTQUEUEDMISSIONEXPORTSRESPONSE
DESCRIPTOR.message_types_by_name['ListMissionExportsRequest'] = _LISTMISSIONEXPORTSREQUEST
DESCRIPTOR.message_types_by_name['ListMissionExportsResponse'] = _LISTMISSIONEXPORTSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteWorkflowRequest'] = _DELETEWORKFLOWREQUEST
DESCRIPTOR.message_types_by_name['DeleteWorkflowResponse'] = _DELETEWORKFLOWRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Workflow = _reflection.GeneratedProtocolMessageType('Workflow', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOW,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:Workflow)
  })
_sym_db.RegisterMessage(Workflow)

WorkflowRequest = _reflection.GeneratedProtocolMessageType('WorkflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowRequest)
  })
_sym_db.RegisterMessage(WorkflowRequest)

WorkflowResponse = _reflection.GeneratedProtocolMessageType('WorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowResponse)
  })
_sym_db.RegisterMessage(WorkflowResponse)

TransitionWorkflowStatusRequest = _reflection.GeneratedProtocolMessageType('TransitionWorkflowStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONWORKFLOWSTATUSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionWorkflowStatusRequest)
  })
_sym_db.RegisterMessage(TransitionWorkflowStatusRequest)

TransitionWorkflowStatusResponse = _reflection.GeneratedProtocolMessageType('TransitionWorkflowStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONWORKFLOWSTATUSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionWorkflowStatusResponse)
  })
_sym_db.RegisterMessage(TransitionWorkflowStatusResponse)

QueueMissionScanRequest = _reflection.GeneratedProtocolMessageType('QueueMissionScanRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONSCANREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionScanRequest)
  })
_sym_db.RegisterMessage(QueueMissionScanRequest)

QueueMissionScanResponse = _reflection.GeneratedProtocolMessageType('QueueMissionScanResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONSCANRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionScanResponse)
  })
_sym_db.RegisterMessage(QueueMissionScanResponse)

ListQueuedMissionScansResponse = _reflection.GeneratedProtocolMessageType('ListQueuedMissionScansResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUEDMISSIONSCANSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListQueuedMissionScansResponse)
  })
_sym_db.RegisterMessage(ListQueuedMissionScansResponse)

ListMissionScansRequest = _reflection.GeneratedProtocolMessageType('ListMissionScansRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSCANSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionScansRequest)
  })
_sym_db.RegisterMessage(ListMissionScansRequest)

ListMissionScansResponse = _reflection.GeneratedProtocolMessageType('ListMissionScansResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSCANSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionScansResponse)
  })
_sym_db.RegisterMessage(ListMissionScansResponse)

ListRelatedMissionScansByIdRequest = _reflection.GeneratedProtocolMessageType('ListRelatedMissionScansByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRELATEDMISSIONSCANSBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListRelatedMissionScansByIdRequest)
  })
_sym_db.RegisterMessage(ListRelatedMissionScansByIdRequest)

ListRelatedMissionScansByIdResponse = _reflection.GeneratedProtocolMessageType('ListRelatedMissionScansByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRELATEDMISSIONSCANSBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListRelatedMissionScansByIdResponse)
  })
_sym_db.RegisterMessage(ListRelatedMissionScansByIdResponse)

QueueMissionExportRequest = _reflection.GeneratedProtocolMessageType('QueueMissionExportRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONEXPORTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionExportRequest)
  })
_sym_db.RegisterMessage(QueueMissionExportRequest)

QueueMissionExportResponse = _reflection.GeneratedProtocolMessageType('QueueMissionExportResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEMISSIONEXPORTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:QueueMissionExportResponse)
  })
_sym_db.RegisterMessage(QueueMissionExportResponse)

ListQueuedMissionExportsResponse = _reflection.GeneratedProtocolMessageType('ListQueuedMissionExportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUEUEDMISSIONEXPORTSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListQueuedMissionExportsResponse)
  })
_sym_db.RegisterMessage(ListQueuedMissionExportsResponse)

ListMissionExportsRequest = _reflection.GeneratedProtocolMessageType('ListMissionExportsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONEXPORTSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionExportsRequest)
  })
_sym_db.RegisterMessage(ListMissionExportsRequest)

ListMissionExportsResponse = _reflection.GeneratedProtocolMessageType('ListMissionExportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONEXPORTSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionExportsResponse)
  })
_sym_db.RegisterMessage(ListMissionExportsResponse)

DeleteWorkflowRequest = _reflection.GeneratedProtocolMessageType('DeleteWorkflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKFLOWREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteWorkflowRequest)
  })
_sym_db.RegisterMessage(DeleteWorkflowRequest)

DeleteWorkflowResponse = _reflection.GeneratedProtocolMessageType('DeleteWorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKFLOWRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteWorkflowResponse)
  })
_sym_db.RegisterMessage(DeleteWorkflowResponse)



_WORKFLOWAPI = _descriptor.ServiceDescriptor(
  name='WorkflowApi',
  full_name='WorkflowApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1801,
  serialized_end=2619,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateWorkflow',
    full_name='WorkflowApi.FindOrCreateWorkflow',
    index=0,
    containing_service=None,
    input_type=_WORKFLOWREQUEST,
    output_type=_WORKFLOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransitionWorkflowStatus',
    full_name='WorkflowApi.TransitionWorkflowStatus',
    index=1,
    containing_service=None,
    input_type=_TRANSITIONWORKFLOWSTATUSREQUEST,
    output_type=_TRANSITIONWORKFLOWSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteWorkflow',
    full_name='WorkflowApi.DeleteWorkflow',
    index=2,
    containing_service=None,
    input_type=_DELETEWORKFLOWREQUEST,
    output_type=_DELETEWORKFLOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueueMissionExport',
    full_name='WorkflowApi.QueueMissionExport',
    index=3,
    containing_service=None,
    input_type=_QUEUEMISSIONEXPORTREQUEST,
    output_type=_QUEUEMISSIONEXPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListQueuedMissionExports',
    full_name='WorkflowApi.ListQueuedMissionExports',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTQUEUEDMISSIONEXPORTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMissionExports',
    full_name='WorkflowApi.ListMissionExports',
    index=5,
    containing_service=None,
    input_type=_LISTMISSIONEXPORTSREQUEST,
    output_type=_LISTMISSIONEXPORTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueueMissionScan',
    full_name='WorkflowApi.QueueMissionScan',
    index=6,
    containing_service=None,
    input_type=_QUEUEMISSIONSCANREQUEST,
    output_type=_QUEUEMISSIONSCANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListQueuedMissionScans',
    full_name='WorkflowApi.ListQueuedMissionScans',
    index=7,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTQUEUEDMISSIONSCANSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMissionScans',
    full_name='WorkflowApi.ListMissionScans',
    index=8,
    containing_service=None,
    input_type=_LISTMISSIONSCANSREQUEST,
    output_type=_LISTMISSIONSCANSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRelatedMissionScansById',
    full_name='WorkflowApi.ListRelatedMissionScansById',
    index=9,
    containing_service=None,
    input_type=_LISTRELATEDMISSIONSCANSBYIDREQUEST,
    output_type=_LISTRELATEDMISSIONSCANSBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKFLOWAPI)

DESCRIPTOR.services_by_name['WorkflowApi'] = _WORKFLOWAPI

# @@protoc_insertion_point(module_scope)
